@@ -11,7 +11,7 @@ use PhpMyAdmin\SqlParser\TokensList;
 
 use function array_key_exists;
 use function in_array;
-use function is_numeric;
+use function is_int;
 use function is_string;
 use function trim;
 
@@ -131,7 +131,10 @@ class AlterOperation extends Component
         'BY' => 2,
         'FOREIGN' => 2,
         'FULLTEXT' => 2,
-        'KEY' => 2,
+        'KEY' => [
+            2,
+            'var',
+        ],
         'KEYS' => 2,
         'PARTITION' => 2,
         'PARTITION BY' => 2,
@@ -237,11 +240,7 @@ class AlterOperation extends Component
         'ON COMPLETION PRESERVE' => 5,
         'ON COMPLETION NOT PRESERVE' => 5,
         'RENAME' => 6,
-        'TO' => [
-            7,
-            'expr',
-            ['parseField' => 'table'],
-        ],
+        'TO' => [7, 'expr', ['parseField' => 'table', 'breakOnAlias' => true]],
         'ENABLE' => 8,
         'DISABLE' => 8,
         'DISABLE ON SLAVE' => 8,
@@ -252,6 +251,27 @@ class AlterOperation extends Component
         'DO' => 10,
     ];
 
+    /**
+     * All routine (procedure or function) options.
+     *
+     * @var array<string, int|array<int, int|string>>
+     * @psalm-var array<string, (positive-int|array{positive-int, ('var'|'var='|'expr'|'expr=')})>
+     */
+    public static $ROUTINE_OPTIONS = [
+        'COMMENT' => [
+            1,
+            'var',
+        ],
+        'LANGUAGE SQL' => 2,
+        'CONTAINS SQL' => 3,
+        'NO SQL' => 3,
+        'READS SQL DATA' => 3,
+        'MODIFIES SQL DATA' => 3,
+        'SQL SECURITY' => 4,
+        'DEFINER' => 5,
+        'INVOKER' => 5,
+    ];
+
     /**
      * Options of this operation.
      *
@@ -412,7 +432,7 @@ class AlterOperation extends Component
 
                 $state = 2;
             } elseif ($state === 2) {
-                if (is_string($token->value) || is_numeric($token->value)) {
+                if (is_string($token->value) || is_int($token->value)) {
                     $arrayKey = $token->value;
                 } else {
                     $arrayKey = $token->token;
@@ -426,7 +446,11 @@ class AlterOperation extends Component
                     } elseif (($token->value === ',') && ($brackets === 0)) {
                         break;
                     }
-                } elseif (! self::checkIfTokenQuotedSymbol($token) && $token->type !== Token::TYPE_STRING) {
+                } elseif (
+                    ! self::checkIfTokenQuotedSymbol($token) &&
+                    $token->type !== Token::TYPE_STRING &&
+                    $token->value !== 'CHECK'
+                ) {
                     if (isset(Parser::$STATEMENT_PARSERS[$arrayKey]) && Parser::$STATEMENT_PARSERS[$arrayKey] !== '') {
                         $list->idx++; // Ignore the current token
                         $nextToken = $list->getNext();
