@@ -1,19 +1,22 @@
 <?php
 
+declare(strict_types=1);
+
+namespace PhpMyAdmin\SqlParser;
+
+use Exception;
+
 /**
  * Defines the core helper infrastructure of the library.
  */
-
-namespace PhpMyAdmin\SqlParser;
-
 class Core
 {
     /**
      * Whether errors should throw exceptions or just be stored.
      *
-     * @var bool
-     *
      * @see static::$errors
+     *
+     * @var bool
      */
     public $strict = false;
 
@@ -24,24 +27,27 @@ class Core
      * error might be false positive or a partial result (even a bad one)
      * might be needed.
      *
-     * @var \Exception[]
-     *
      * @see Core::error()
+     *
+     * @var Exception[]
      */
-    public $errors = array();
+    public $errors = [];
 
     /**
      * Creates a new error log.
      *
-     * @param \Exception $error the error exception
+     * @param Exception $error the error exception
      *
-     * @throws \Exception throws the exception, if strict mode is enabled
+     * @return void
+     *
+     * @throws Exception throws the exception, if strict mode is enabled.
      */
     public function error($error)
     {
         if ($this->strict) {
             throw $error;
         }
+
         $this->errors[] = $error;
     }
 }
