@@ -50,7 +50,7 @@ class ArrayObjTest extends TestCase
     /**
      * @return string[][]
      */
-    public function parseProvider(): array
+    public static function parseProvider(): array
     {
         return [
             ['parser/parseArrayErr1'],
