@@ -53,7 +53,7 @@ class ExpressionTest extends TestCase
     /**
      * @return string[][]
      */
-    public function parseErrProvider(): array
+    public static function parseErrProvider(): array
     {
         return [
             /*
