@@ -32,7 +32,7 @@ class LimitTest extends TestCase
     /**
      * @return string[][]
      */
-    public function parseProvider(): array
+    public static function parseProvider(): array
     {
         return [
             ['parser/parseLimitErr1'],
