@@ -11,14 +11,14 @@ use PhpMyAdmin\SqlParser\Tests\TestCase;
 
 class ReferenceTest extends TestCase
 {
-    public function testParse()
+    public function testParse(): void
     {
         $component = Reference::parse(new Parser(), $this->getTokensList('tbl (id)'));
         $this->assertEquals('tbl', $component->table->table);
         $this->assertEquals(['id'], $component->columns);
     }
 
-    public function testBuild()
+    public function testBuild(): void
     {
         $component = new Reference(new Expression('`tbl`'), ['id']);
         $this->assertEquals('`tbl` (`id`)', Reference::build($component));
