@@ -19,10 +19,11 @@ class ParameterTest extends TestCase
     /**
      * @return string[][]
      */
-    public function parameterProvider(): array
+    public static function parameterProvider(): array
     {
         return [
             ['misc/parseParameter'],
+            ['misc/parseParameter2'],
         ];
     }
 }
