@@ -19,7 +19,7 @@ class AlterStatementTest extends TestCase
     /**
      * @return string[][]
      */
-    public function alterProvider(): array
+    public static function alterProvider(): array
     {
         return [
             ['parser/parseAlter'],
@@ -42,9 +42,12 @@ class AlterStatementTest extends TestCase
             ['parser/parseAlterErr4'],
             ['parser/parseAlterTableRenameIndex1'],
             ['parser/parseAlterTableRenameIndex2'],
+            ['parser/parseAlterTableRenameKey1'],
+            ['parser/parseAlterTableRenameKey2'],
             ['parser/parseAlterTablePartitionByRange1'],
             ['parser/parseAlterTablePartitionByRange2'],
             ['parser/parseAlterTableCoalescePartition'],
+            ['parser/parseAlterTableAddColumnWithCheck'],
             ['parser/parseAlterTableAddSpatialIndex1'],
             ['parser/parseAlterTableDropAddIndex1'],
             ['parser/parseAlterTableDropColumn1'],
@@ -94,6 +97,18 @@ class AlterStatementTest extends TestCase
             ['parser/parseAlterEventWithOtherDefiners'],
             ['parser/parseAlterRenameColumn'],
             ['parser/parseAlterRenameColumns'],
+            ['parser/parseAlterFunction1'],
+            ['parser/parseAlterFunction2'],
+            ['parser/parseAlterFunction3'],
+            ['parser/parseAlterFunction4'],
+            ['parser/parseAlterFunction5'],
+            ['parser/parseAlterFunction6'],
+            ['parser/parseAlterProcedure1'],
+            ['parser/parseAlterProcedure2'],
+            ['parser/parseAlterProcedure3'],
+            ['parser/parseAlterProcedure4'],
+            ['parser/parseAlterProcedure5'],
+            ['parser/parseAlterProcedure6'],
         ];
     }
 }
