@@ -19,7 +19,7 @@ class UpdateStatementTest extends TestCase
     /**
      * @return string[][]
      */
-    public function updateProvider(): array
+    public static function updateProvider(): array
     {
         return [
             ['parser/parseUpdate1'],
@@ -30,6 +30,7 @@ class UpdateStatementTest extends TestCase
             ['parser/parseUpdate6'],
             ['parser/parseUpdate7'],
             ['parser/parseUpdateErr'],
+            ['parser/parseUpdateEmptySet'],
         ];
     }
 }
